@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2024
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -554,7 +554,7 @@ ConvexHullSolver::find_irredundant_representation(const Matrix<Rational>& Points
 
    Bitset V(Points.rows());
    for (Int index = D.Q->lastdv+1, end = D.P->m_A+D.P->d; index <= end; ++index)
-      if ( !checkindex(D.P,D.Q,index) )
+      if ( !checkindex(D.P,D.Q,index,0) )
          V += D.Q->inequality[index - D.Q->lastdv]-1;
 
    return std::pair< Bitset, Matrix<Rational> >(V,AH);
